# EIDA Consistency Report: `LMU`

- Seed: `674788`
- Time: `2025-09-08T17:00:16.322825+00:00`
- Epochs requested: `20`
- Candidates requested: `20`
- Candidates tested: `None`
- Station queries performed: `None`
- Duration/epoch: `600 s`
- Total checks run: `20`
- Consistent: `20`
- Inconsistent: `0`
- Score: **100.0 %**

## Inconsistency Breakdown
- Availability says YES, Dataselect says NO: `0`
- Availability says NO, Dataselect says YES: `0`

## Dataselect Response Types
- **SingleTrace**: `20`

---

## Detailed Results
### `BW.RTSH..EHE`
- Window: `2010-07-15T07:37:29 → 2010-07-15T07:47:29`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.DHFO..EHN`
- Window: `2011-10-02T16:36:45 → 2011-10-02T16:46:45`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Z3.A035B.00.HHZ`
- Window: `2020-01-11T21:45:49 → 2020-01-11T21:55:49`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Z3.A366A..HHN`
- Window: `2016-03-24T23:24:07 → 2016-03-24T23:34:07`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.RNON..EHN`
- Window: `2012-11-05T06:50:14 → 2012-11-05T07:00:14`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.ALFT..BHZ`
- Window: `2020-03-20T16:25:55 → 2020-03-20T16:35:55`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.NORI..EHN`
- Window: `2021-06-22T13:26:32 → 2021-06-22T13:36:32`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.PFORL..HJZ`
- Window: `2013-05-17T16:41:43 → 2013-05-17T16:51:43`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Z3.A260A.00.HHZ`
- Window: `2019-10-03T12:10:44 → 2019-10-03T12:20:44`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.BE2..EHN`
- Window: `2014-01-17T01:19:43 → 2014-01-17T01:29:43`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Z3.A363A.00.HHN`
- Window: `2018-11-25T07:13:43 → 2018-11-25T07:23:43`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Z3.A368A..HHZ`
- Window: `2016-03-14T13:26:36 → 2016-03-14T13:36:36`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.MNH..EHZ`
- Window: `2022-11-08T08:34:48 → 2022-11-08T08:44:48`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Z3.A352A.00.HHZ`
- Window: `2018-11-21T15:32:28 → 2018-11-21T15:42:28`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `Z3.A116B.00.HHN`
- Window: `2019-02-13T00:32:05 → 2019-02-13T00:42:05`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.MASC..EHZ`
- Window: `2010-10-08T12:16:46 → 2010-10-08T12:26:46`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.MANZ..EHE`
- Window: `2013-05-22T00:37:39 → 2013-05-22T00:47:39`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.MSBB..EHZ`
- Window: `2016-08-12T05:58:53 → 2016-08-12T06:08:53`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.BIB..HHN`
- Window: `2019-11-15T17:58:49 → 2019-11-15T18:08:49`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BW.MGS04..HHZ`
- Window: `2018-01-10T17:23:50 → 2018-01-10T17:33:50`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`
